@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2001, 2002, 2003, 2004 Philip Blundell <philb@gnu.org>
+ *               2004, 2005 Florian Boor <florian@kernelconcepts.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -8,7 +9,7 @@
  */
 
 /*
- * $Id: main.c,v 1.110 2005/03/16 14:50:47 florian Exp $
+ * $Id: main.c,v 1.126 2006/02/03 13:05:28 florian Exp $
  *
  */
 
@@ -16,7 +17,6 @@
 #include <libintl.h>
 #include <stdlib.h>
 #include <string.h>
-#include <libdisplaymigration/displaymigration.h>
 #include <unistd.h>
 #include <locale.h>
 #include <time.h>
@@ -34,7 +34,7 @@
 #include <gpe/spacing.h>
 
 #include "support.h"
-#include "db.h"
+#include <gpe/contacts-db.h>
 #include "structure.h"
 #include "proto.h"
 #include "main.h"
@@ -42,14 +42,11 @@
 #include "import-vcard.h"
 #include "finddlg.h"
 
-#define SYSTEM_PIXMAPS_DIR PREFIX "/share/pixmaps/"
 #define MY_PIXMAPS_DIR "gpe-contacts/"
-#define TAB_CONFIG_LOCAL ".contacts-tab"
-#define TAB_CONFIG_GLOBAL "/etc/gpe/contacts-tab.conf"
 
 GtkWidget *categories_smenu;
 GtkWidget *mainw;
-GtkListStore *list_store;
+static GtkListStore *list_store;
 GtkWidget *list_view;
 GtkWidget *search_entry;
 GtkWidget *popup_menu;
@@ -61,22 +58,22 @@ gboolean mode_large_screen;
 gboolean scroll_delay = FALSE;
 gboolean do_wrap = FALSE;
 
+#define DEFAULT_STRUCTURE PREFIX "/share/gpe-contacts/default-layout.xml"
+#define LARGE_STRUCTURE PREFIX "/share/gpe-contacts/default-layout-bigscreen.xml"
+
 struct gpe_icon my_icons[] = {
-  {"edit"},
-  {"delete"},
-  {"cancel"},
   {"frame", MY_PIXMAPS_DIR "frame"},
   {"notebook", MY_PIXMAPS_DIR "notebook"},
   {"entry", MY_PIXMAPS_DIR "entry"},
-  {"icon", SYSTEM_PIXMAPS_DIR "gpe-contacts.png" },
+  {"icon", PREFIX "/share/pixmaps/gpe-contacts.png" },
   {NULL, NULL}
 };
 
 static void
 menu_do_edit (void)
 {
-  struct person *p;
-  p = db_get_by_uid (menu_uid);
+  struct contacts_person *p;
+  p = contacts_db_get_by_uid (menu_uid);
   edit_person (p,  _("Edit Contact"), FALSE);
 }
 
@@ -86,7 +83,7 @@ menu_do_delete (void)
   if (gpe_question_ask (_("Really delete this contact?"), _("Confirm"), 
 			"question", "!gtk-cancel", NULL, "!gtk-delete", NULL, NULL) == 1)
     {
-      if (db_delete_by_uid (menu_uid))
+      if (contacts_db_delete_by_uid (menu_uid))
         update_display ();
     }
 }
@@ -108,7 +105,7 @@ load_panel_config (void)
 
   g_list_free (wlist);
 
-  count = db_get_config_values (CONFIG_PANEL, &list);
+  count = contacts_db_get_config_values (CONFIG_PANEL, &list);
   for (i = 0; i < count; i++)
     {
       lleft = gtk_label_new (list[2 * i + 2]);
@@ -124,7 +121,7 @@ load_panel_config (void)
 			GTK_FILL, 2, 2);
     }
 
-  db_free_result (list);
+  contacts_db_free_result (list);
 }
 
 static void
@@ -149,14 +146,14 @@ update_categories (void)
 static void
 new_contact (GtkWidget * widget, gpointer d)
 {
-  struct person *p;
+  struct contacts_person *p;
   GtkWidget *new_button, *edit_button;
 	  
   new_button = g_object_get_data(G_OBJECT(mainw), "new-button");
   edit_button = g_object_get_data(G_OBJECT(mainw), "edit-button");
   gtk_widget_set_sensitive (new_button, FALSE);
   gtk_widget_set_sensitive (edit_button, FALSE);
-  p = new_person ();
+  p = contacts_new_person ();
   edit_person (p, _("New Contact"), FALSE);
 }
 
@@ -170,7 +167,7 @@ edit_contact (GtkWidget * widget, gpointer d)
   if (gtk_tree_selection_get_selected (sel, &model, &iter))
     {
       guint uid;
-      struct person *p;
+      struct contacts_person *p;
       GtkWidget *new_button, *edit_button;
 	  
 	  new_button = g_object_get_data(G_OBJECT(mainw), "new-button");
@@ -178,7 +175,7 @@ edit_contact (GtkWidget * widget, gpointer d)
       gtk_widget_set_sensitive (new_button, FALSE);
       gtk_widget_set_sensitive (edit_button, FALSE);
       gtk_tree_model_get (GTK_TREE_MODEL (model), &iter, 1, &uid, -1);
-      p = db_get_by_uid (uid);
+      p = contacts_db_get_by_uid (uid);
       edit_person (p, _("Edit Contact"), FALSE);
     }
 }
@@ -206,7 +203,7 @@ delete_contact (GtkWidget * widget, gpointer d)
             }
           else
             path = gtk_tree_path_new_first();
-          if (db_delete_by_uid (uid))
+          if (contacts_db_delete_by_uid (uid))
             {
               update_display ();
               gtk_tree_view_set_cursor(GTK_TREE_VIEW(list_view), path, 
@@ -260,7 +257,7 @@ get_tag_name(const gchar* tag)
 }
 
 static gboolean
-pop_singles (GtkWidget *vbox, GSList *list, struct person *p)
+pop_singles (GtkWidget *vbox, GSList *list, struct contacts_person *p)
 {
   if (list)
     {
@@ -272,13 +269,13 @@ pop_singles (GtkWidget *vbox, GSList *list, struct person *p)
         {
           GSList *next = list->next;
           edit_thing_t e = list->data;
-          struct tag_value *tv = NULL;
+          struct contacts_tag_value *tv = NULL;
           GtkWidget *w;
           GtkWidget *l;
           gchar *name;
 
           if (e && e->tag) 
-             tv = db_find_tag(p, e->tag);
+             tv = contacts_db_find_tag(p, e->tag);
           if (tv && tv->value)
             {
               if (table == NULL) 
@@ -330,7 +327,7 @@ pop_singles (GtkWidget *vbox, GSList *list, struct person *p)
 }
 
 static gboolean
-build_children (GtkWidget *vbox, GSList *children, struct person *p)
+build_children (GtkWidget *vbox, GSList *children, struct contacts_person *p)
 {
   gboolean result = FALSE;
   GSList *child;
@@ -339,12 +336,12 @@ build_children (GtkWidget *vbox, GSList *children, struct person *p)
   for (child = children; child; child = child->next)
     {
       edit_thing_t e = child->data;
-      struct tag_value *tv = NULL;
+      struct contacts_tag_value *tv = NULL;
       GtkWidget *w;
       
       if (e && e->tag)
         {
-          tv = db_find_tag(p, e->tag);
+          tv = contacts_db_find_tag(p, e->tag);
         }
       if (!e->hidden)
         switch (e->type)
@@ -459,14 +456,14 @@ build_children (GtkWidget *vbox, GSList *children, struct person *p)
 }
 
 static int
-show_details (struct person *p)
+show_details (struct contacts_person *p)
 {
   GtkWidget *lleft, *lright;
   GtkTable *table;
   gint i;
   gpointer pchild;
   gchar *tagname;
-  struct tag_value *curtag;
+  struct contacts_tag_value *curtag;
   GList *wlist, *witer;
   GSList *page;
   GtkWidget *label;
@@ -546,9 +543,9 @@ show_details (struct person *p)
                 continue;
               lleft = ((GtkTableChild *) pchild)->widget;
               tagname =
-                db_get_config_tag (CONFIG_PANEL,
+                contacts_db_get_config_tag (CONFIG_PANEL,
                            g_strdup (gtk_label_get_text(GTK_LABEL (lleft))));
-              curtag = db_find_tag (p, tagname);
+              curtag = contacts_db_find_tag (p, tagname);
               if (curtag != NULL)
                 {
                   gtk_label_set_text (GTK_LABEL (lright), curtag->value);
@@ -571,7 +568,7 @@ show_details_window(GtkWidget *btn)
   GtkTreeSelection *sel;
   GtkTreeModel *model;
   GSList *page;
-  struct person *p;
+  struct contacts_person *p;
   
   /* get person data */
   sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(list_view));
@@ -579,7 +576,7 @@ show_details_window(GtkWidget *btn)
     {
       gint id;
       gtk_tree_model_get (model, &iter, 1, &id, -1);
-      p = db_get_by_uid (id);
+      p = contacts_db_get_by_uid (id);
     }
   else
     return;
@@ -641,7 +638,7 @@ show_details_window(GtkWidget *btn)
   gtk_widget_show_all(dlgDetail);
   gtk_dialog_run(GTK_DIALOG(dlgDetail));
   gtk_widget_destroy(dlgDetail);
-  discard_person (p);
+  contacts_discard_person (p);
 }
 
 void
@@ -649,7 +646,7 @@ selection_made (GtkTreeSelection *sel, GObject *o)
 {
   GtkTreeIter iter;
   guint id;
-  struct person *p;
+  struct contacts_person *p;
   GtkTreeModel *model;
   GtkWidget *edit_button, *delete_button, *new_button, *details_button;
 
@@ -662,11 +659,9 @@ selection_made (GtkTreeSelection *sel, GObject *o)
     {
       gtk_tree_model_get (model, &iter, 1, &id, -1);
 
-      p = db_get_by_uid (id);
-    
+      p = contacts_db_get_by_uid (id);
       show_details (p);
-
-      discard_person (p);
+      contacts_discard_person (p);
 		
       gtk_widget_set_sensitive (edit_button, TRUE);
       gtk_widget_set_sensitive (delete_button, TRUE);
@@ -685,10 +680,8 @@ selection_made (GtkTreeSelection *sel, GObject *o)
 }
 
 static gboolean
-match_for_search (struct person *p, const gchar *text, struct gpe_pim_category *cat)
+match_for_search (struct contacts_person *p, const gchar *text, struct gpe_pim_category *cat)
 {
-  gchar *gn;
-  gchar *mn;
   gchar *fn;
   gchar *name;
   gchar *company;
@@ -697,16 +690,6 @@ match_for_search (struct person *p, const gchar *text, struct gpe_pim_category *
   
   if (text)
     {
-      if (p->given_name)
-        gn = g_utf8_strdown(p->given_name, -1);
-      else
-        gn = g_strdup("");
-      
-      if (p->middle_name)
-        mn = g_utf8_strdown(p->middle_name, -1);
-      else
-        mn = g_strdup("");
-      
       if (p->family_name)
         fn = g_utf8_strdown(p->family_name, -1);
       else
@@ -722,21 +705,15 @@ match_for_search (struct person *p, const gchar *text, struct gpe_pim_category *
       else
         company = g_strdup("");
       
-      if (!g_str_has_prefix(gn, text) 
-          && !g_str_has_prefix(fn, text) 
+      if (!g_str_has_prefix(fn, text) 
           && !g_str_has_prefix(name, text)
-          && !g_str_has_prefix(mn, text)
           && !g_str_has_prefix(company, text))
         {
-          if (gn) g_free(gn);
-          if (mn) g_free(mn);
           if (fn) g_free(fn);
           if (name) g_free(name);
           if (company) g_free(company);
           return FALSE;
         }
-      if (gn) g_free(gn);
-      if (mn) g_free(mn);
       if (fn) g_free(fn);
       if (name) g_free(name);
       if (company) g_free(company);
@@ -746,10 +723,10 @@ match_for_search (struct person *p, const gchar *text, struct gpe_pim_category *
     {
       GSList *l;
       gboolean found = FALSE;
-      struct person *per = db_get_by_uid (p->id);
+      struct contacts_person *per = contacts_db_get_by_uid (p->id);
       for (l = per->data; l; l = l->next)
         {
-          struct tag_value *v = l->data;
+          struct contacts_tag_value *v = l->data;
           if (!strcasecmp (v->tag, "CATEGORY") && v->value)
             {
               guint c = atoi (v->value);
@@ -760,7 +737,7 @@ match_for_search (struct person *p, const gchar *text, struct gpe_pim_category *
                 }
             }
         }
-      discard_person(per);
+      contacts_discard_person(per);
       if (!found)
         return FALSE;
     }
@@ -792,22 +769,26 @@ do_search (GObject *obj, GtkWidget *entry)
       g_slist_free (l);
     }
 
-  /* Todo cat  */
-  sel_entries = db_get_entries_list (text, cat_id);
-  sel_entries = g_slist_sort (sel_entries, (GCompareFunc)sort_entries);
+  sel_entries = contacts_db_get_entries_list (text, cat_id);
+  
+  if (cat_id) 
+    g_free(cat_id);
+      
+  sel_entries = g_slist_sort (sel_entries, (GCompareFunc)contacts_sort_entries);
 
   gtk_list_store_clear (list_store);
   show_details(NULL);
 
   for (iter = sel_entries; iter; iter = iter->next)
     {
-      struct person *p = iter->data;
+      struct contacts_person *p = iter->data;
       GtkTreeIter titer;
       
       gtk_list_store_append (list_store, &titer);
-      gtk_list_store_set (list_store, &titer, 0, p->name, 1, p->id, -1);
+      gtk_list_store_set (list_store, &titer, 0, 
+                          (p->name[0] != '(') ? p->name : p->company, 1, p->id, -1);
 
-      discard_person (p);
+      contacts_discard_person (p);
     }
   
   g_slist_free (sel_entries);
@@ -844,23 +825,30 @@ do_find (void)
     }
 
   all_entries = do_find_contacts(GTK_WINDOW(mainw), cat_id);
-  all_entries = g_slist_sort (all_entries, (GCompareFunc)sort_entries);
+
+  if (cat_id) 
+    g_free(cat_id);
+  if (!all_entries)
+    return;
+  
+  all_entries = g_slist_sort (all_entries, (GCompareFunc)contacts_sort_entries);
 
   gtk_list_store_clear (list_store);
   show_details(NULL);
 
   for (iter = all_entries; iter; iter = iter->next)
     {
-      struct person *p = iter->data;
+      struct contacts_person *p = iter->data;
       GtkTreeIter titer;
       
       if (match_for_search (p, NULL, c))
         {
 	      gtk_list_store_append (list_store, &titer);
-	      gtk_list_store_set (list_store, &titer, 0, p->name, 1, p->id, -1);
+	      gtk_list_store_set (list_store, &titer, 0, 
+                              (p->name[0] != '(') ? p->name : p->company, 1, p->id, -1);
         }
 
-      discard_person (p);
+      contacts_discard_person (p);
     }
   
   g_slist_free (all_entries);
@@ -1192,26 +1180,18 @@ on_main_focus(GtkWindow *window,  GdkEventExpose *event,gpointer user_data)
 {
   GtkWidget *searchentry = user_data;
   
-  gtk_widget_grab_focus(searchentry);
   gtk_editable_select_region(GTK_EDITABLE(searchentry),0,-1);
 }
 
 static int 
 import_one_file(const gchar *filename)
 {
-  GError *err = NULL;
-  gchar *content = NULL;
-  gsize count = 0;
   int result = 0;
-	
-  if (g_file_get_contents(filename, &content, &count, &err))
-    {
-      result = import_vcard(content, count);
-      g_free(content);
-    }
-  else
-    result = -1;
+
+  result = import_vcard(filename);
+
   return result;
+
 }
 
 static void
@@ -1256,7 +1236,7 @@ on_import_vcard (GtkWidget *widget, gpointer data)
       gtk_widget_destroy(feedbackdlg);
     }
   gtk_widget_destroy(filesel);
-  db_open(FALSE);
+  contacts_db_open(FALSE);
   update_display();
 }
 
@@ -1271,23 +1251,33 @@ create_main (gboolean edit_structure)
   GtkWidget *pDetail;
   GtkWidget *tabDetail;
   GtkWidget *toolbar, *pw;
-  GtkWidget *b, *btnNew, *btnDetails;
+  GtkToolItem *b, *btnNew;
   GtkCellRenderer *renderer;
   GtkTreeViewColumn *column;
   GtkTreeSelection *tree_sel;
   GtkWidget *scrolled_window;
   GtkWidget *lStatus = NULL;
+  GtkTooltips *tooltips;
   gint size_x, size_y;
 
-  /* screen layout detection */
+  /* default screen size and dimension base */
   size_x = gdk_screen_width();
   size_y = gdk_screen_height();  
-  size_x /= 4;
+  size_x /= 3;
   size_y /= 3;
-  if (size_x < 240) size_x = 240;
-  if (size_y < 320) size_y = 320;
-
-  /* main window */
+  
+  if (mode_large_screen)
+    {
+       size_x = 720;
+       size_y = 400;
+    }
+  else
+    {
+      if (size_x < 240) size_x = 240;
+      if (size_y < 320) size_y = 320;
+    }
+    
+  /*** main window ***/
   main_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (main_window), _("Contacts"));
   gtk_window_set_default_size (GTK_WINDOW (main_window), size_x, size_y);
@@ -1295,66 +1285,105 @@ create_main (gboolean edit_structure)
   vbox1 = gtk_vbox_new (FALSE, 0);
   gtk_container_add (GTK_CONTAINER (main_window), vbox1);
 
+  /** toolbar widgets **/
   toolbar = gtk_toolbar_new ();
   gtk_toolbar_set_orientation (GTK_TOOLBAR (toolbar),
-			       GTK_ORIENTATION_HORIZONTAL);
-
+                               GTK_ORIENTATION_HORIZONTAL);
+  tooltips = gtk_tooltips_new();
+  
   gtk_box_pack_start (GTK_BOX (vbox1), toolbar, FALSE, FALSE, 0);
 
-  btnNew = gtk_toolbar_insert_stock (GTK_TOOLBAR (toolbar), GTK_STOCK_NEW,
-			    _("Tap this button to add a new contact."), NULL,
-			    G_CALLBACK (new_contact), NULL, -1);
+  /* new button */
+  btnNew = gtk_tool_button_new_from_stock(GTK_STOCK_NEW);
+  gtk_tool_item_set_tooltip(btnNew, tooltips, 
+                            _("Tap this button to add a new contact."), NULL);
+  g_signal_connect(G_OBJECT(btnNew), "clicked", G_CALLBACK(new_contact), NULL);
+  gtk_toolbar_insert(GTK_TOOLBAR(toolbar), btnNew, -1);
+  
   g_object_set_data (G_OBJECT (main_window), "new-button", btnNew);
 
-  pw = gtk_image_new_from_pixbuf (gpe_find_icon_scaled ("edit", 
-							gtk_toolbar_get_icon_size (GTK_TOOLBAR (toolbar))));
-
-  b = gtk_toolbar_append_item (GTK_TOOLBAR (toolbar), _("Edit"), 
-			       _("Tap here to edit the selected contact."), NULL,
-			       pw, (GtkSignalFunc) edit_contact, NULL);
+  /* edit button */
+  b = gtk_tool_button_new_from_stock(GTK_STOCK_EDIT);
+  gtk_tool_item_set_tooltip(b, tooltips, 
+                            _("Tap here to edit the selected contact."), NULL);
+  g_signal_connect(G_OBJECT(b), "clicked", G_CALLBACK(edit_contact), NULL);
+  gtk_toolbar_insert(GTK_TOOLBAR(toolbar), b, -1);
+  
   g_object_set_data (G_OBJECT (main_window), "edit-button", b);
-  gtk_widget_set_sensitive (b, FALSE);
+  gtk_widget_set_sensitive (GTK_WIDGET(b), FALSE);
 
-  b = gtk_toolbar_insert_stock (GTK_TOOLBAR (toolbar), GTK_STOCK_DELETE,
-				_("Tap here to delete the selected contact."), NULL,
-				G_CALLBACK (delete_contact), NULL, -1);
+  /* delete button */
+  b = gtk_tool_button_new_from_stock(GTK_STOCK_DELETE);
+  gtk_tool_item_set_tooltip(b, tooltips, 
+                            _("Tap here to delete the selected contact."), NULL);
+  g_signal_connect(G_OBJECT(b), "clicked", G_CALLBACK(delete_contact), NULL);
+  gtk_toolbar_insert(GTK_TOOLBAR(toolbar), b, -1);
+  
   g_object_set_data (G_OBJECT (main_window), "delete-button", b);
-  gtk_widget_set_sensitive (b, FALSE);
+  gtk_widget_set_sensitive (GTK_WIDGET(b), FALSE);
 
-  if (!mode_landscape)
+  /* separator */
+  b = gtk_separator_tool_item_new();
+  gtk_separator_tool_item_set_draw(GTK_SEPARATOR_TOOL_ITEM(b), TRUE);
+  gtk_toolbar_insert(GTK_TOOLBAR(toolbar), b, -1);
+
+  /* 
+    In portrait screen layout we add a button for the details dialog.
+    If the display is landscape add additional find button. 
+   */
+  if (mode_landscape)
     {
-      pw = gtk_image_new_from_stock (GTK_STOCK_INDEX,
-                                     gtk_toolbar_get_icon_size (GTK_TOOLBAR (toolbar)));
-      btnDetails = gtk_toolbar_append_item (GTK_TOOLBAR (toolbar), _("Details"), 
-                                      _("Tap here to show contacts details."), 
-                                      NULL, pw, G_CALLBACK (show_details_window), NULL);
-      g_object_set_data (G_OBJECT (main_window), "details-button", btnDetails);
+      b = gtk_tool_button_new_from_stock(GTK_STOCK_FIND);
+      gtk_tool_item_set_tooltip(b, tooltips, 
+                                _("Find a contact by searching for any data."), NULL);
+      g_signal_connect(G_OBJECT(b), "clicked", G_CALLBACK(do_find), NULL);
+      gtk_toolbar_insert(GTK_TOOLBAR(toolbar), b, -1);
     }
   else
     {
-      gtk_toolbar_append_space(GTK_TOOLBAR(toolbar));
+      pw = gtk_image_new_from_stock (GTK_STOCK_INDEX,
+                                     gtk_toolbar_get_icon_size (GTK_TOOLBAR (toolbar)));
+      b = gtk_tool_button_new(pw, _("Details"));
+      gtk_tool_item_set_tooltip(b, tooltips, 
+                                _("Tap here to show contacts details."), NULL);
+      g_signal_connect(G_OBJECT(b), "clicked", G_CALLBACK(show_details_window), NULL);
+      gtk_toolbar_insert(GTK_TOOLBAR(toolbar), b, -1);
     
-      b = gtk_toolbar_insert_stock (GTK_TOOLBAR (toolbar), GTK_STOCK_FIND,
-				_("Find a contact by searching for any data."), NULL,
-				G_CALLBACK (do_find), NULL, -1);
+      g_object_set_data (G_OBJECT (main_window), "details-button", b);
     }
   
-  gtk_toolbar_insert_stock (GTK_TOOLBAR (toolbar), GTK_STOCK_PROPERTIES,
-			    _("Properties"), _("Tap here to configure this program."),
-  			    G_CALLBACK (configure), (gpointer)edit_structure, -1);
-				
-  pw = gtk_image_new_from_stock(GTK_STOCK_OPEN, 
-                                gtk_toolbar_get_icon_size(GTK_TOOLBAR (toolbar)));
-  gtk_toolbar_append_item (GTK_TOOLBAR (toolbar),
-			    _("Import"), _("Open file to import a contact from it."), 
-                NULL, pw, G_CALLBACK (on_import_vcard), NULL);
-    
-  gtk_toolbar_append_space(GTK_TOOLBAR(toolbar));
+  /* application properties button */
+  b = gtk_tool_button_new_from_stock(GTK_STOCK_PROPERTIES);
+  gtk_tool_item_set_tooltip(b, tooltips, 
+                            _("Tap here to configure this program."), NULL);
+  g_signal_connect(G_OBJECT(b), "clicked", G_CALLBACK(configure),
+                   (gpointer)edit_structure);
+  gtk_toolbar_insert(GTK_TOOLBAR(toolbar), b, -1);
 
-  gtk_toolbar_insert_stock (GTK_TOOLBAR (toolbar), GTK_STOCK_QUIT,
-			    _("Close"), _("Tap here to exit gpe-contacts."),
-			    G_CALLBACK (gtk_main_quit), NULL, -1);
+  /* import button */
+  pw = gtk_image_new_from_stock (GTK_STOCK_OPEN,
+                                 gtk_toolbar_get_icon_size (GTK_TOOLBAR (toolbar)));
+  b = gtk_tool_button_new(pw, _("Import"));
+  gtk_tool_item_set_tooltip(b, tooltips, 
+                            _("Open file to import a contact from it."), NULL);
+  g_signal_connect(G_OBJECT(b), "clicked", G_CALLBACK(on_import_vcard), NULL);
+  gtk_toolbar_insert(GTK_TOOLBAR(toolbar), b, -1);
 
+  /* another separator */
+  b = gtk_separator_tool_item_new();
+  gtk_separator_tool_item_set_draw(GTK_SEPARATOR_TOOL_ITEM(b), FALSE);
+  gtk_tool_item_set_expand(b, TRUE);
+  gtk_toolbar_insert(GTK_TOOLBAR(toolbar), b, -1);
+
+  /* quit button */
+  b = gtk_tool_button_new_from_stock(GTK_STOCK_QUIT);
+  gtk_tool_item_set_tooltip(b, tooltips, 
+                            _("Tap here to exit gpe-contacts."), NULL);
+  g_signal_connect(G_OBJECT(b), "clicked", G_CALLBACK(gtk_main_quit), NULL);
+  gtk_toolbar_insert(GTK_TOOLBAR(toolbar), b, -1);
+
+
+  /** contacts list **/
   scrolled_window = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window), 
 				  GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
@@ -1369,7 +1398,7 @@ create_main (gboolean edit_structure)
   gtk_container_add (GTK_CONTAINER (scrolled_window), list_view);
   if (mode_landscape)
     {
-      gchar *cfgval = db_get_config_tag(CONFIG_LIST, "pos");
+      gchar *cfgval = contacts_db_get_config_tag(CONFIG_LIST, "pos");
       hbox1 = gtk_hbox_new(FALSE, gpe_get_boxspacing());
       gtk_box_pack_start (GTK_BOX (vbox1), hbox1, TRUE, TRUE, 0);
       if ((cfgval) && !strcmp(cfgval, "right"))
@@ -1406,12 +1435,15 @@ create_main (gboolean edit_structure)
     }
   gtk_box_pack_start (GTK_BOX (vbox1), hbox3, FALSE, FALSE, 0);
 
+  /** status label on larger screens **/
   if (mode_large_screen)
     {
       lStatus = gtk_label_new (NULL);
       gtk_misc_set_alignment(GTK_MISC(lStatus), 1.0, 0.5);
       gtk_box_pack_end (GTK_BOX (hbox3), lStatus, FALSE, FALSE, 3);
     }
+    
+  /** find and categories section **/
   label83 = gtk_label_new (_("Find:"));
   gtk_box_pack_start (GTK_BOX (hbox3), label83, FALSE, FALSE, 0);
 
@@ -1440,18 +1472,21 @@ create_main (gboolean edit_structure)
     g_signal_connect (G_OBJECT (list_view), "cursor-changed", 
 		    G_CALLBACK (list_view_cursor_changed), lStatus);
 
-  gtk_widget_set_events (main_window,GDK_KEY_PRESS_MASK);
-  gtk_widget_set_events (entry1,GDK_KEY_PRESS_MASK);
+  /* set masks and tie up key events for keyboard control */
+  gtk_widget_set_events (main_window, GDK_KEY_PRESS_MASK);
+  gtk_widget_set_events (entry1, GDK_KEY_PRESS_MASK);
   g_signal_connect (G_OBJECT (main_window), "key_press_event", 
-		    G_CALLBACK (window_key_press_event), list_view);
+                    G_CALLBACK (window_key_press_event), list_view);
 
   g_signal_connect (G_OBJECT (toolbar), "key_press_event", 
-		    G_CALLBACK (toolbar_key_press_event), NULL);
+                    G_CALLBACK (toolbar_key_press_event), NULL);
   g_signal_connect (G_OBJECT (entry1), "key_press_event", 
-		    G_CALLBACK (search_entry_key_press_event), btnNew);
+                    G_CALLBACK (search_entry_key_press_event), btnNew);
             
   search_entry = entry1;
 
+  
+  /** detail section **/
   pDetail = gtk_frame_new (_("Contact"));
   
   if (mode_landscape)
@@ -1466,7 +1501,7 @@ create_main (gboolean edit_structure)
   tabDetail = gtk_table_new (1, 2, FALSE);
   gtk_table_set_col_spacings(GTK_TABLE(tabDetail), gpe_get_boxspacing() * 2);
   gtk_container_set_border_width(GTK_CONTAINER(tabDetail), gpe_get_border());
-  if (mode_large_screen)
+  if (mode_landscape)
     {
       GtkWidget *vport;
       scrolled_window = gtk_scrolled_window_new(NULL, NULL);
@@ -1488,8 +1523,6 @@ create_main (gboolean edit_structure)
 		    G_CALLBACK (selection_made), main_window);
   g_signal_connect (G_OBJECT (main_window), "focus-in-event",
 		    G_CALLBACK (on_main_focus), entry1);
-
-  displaymigration_mark_window (main_window);
   
   return main_window;
 }
@@ -1503,7 +1536,7 @@ main (int argc, char *argv[])
   gchar *ifile = NULL;
   GtkTreePath *path;
   gint size_x, size_y;
-  
+    
 #ifdef ENABLE_NLS
   setlocale (LC_ALL, "");
 
@@ -1527,17 +1560,20 @@ main (int argc, char *argv[])
   /* check command line args */
   while ((arg = getopt(argc, argv, "ni:v")) >= 0)
   {
+    /* -n suppress edition of the structure in the preferences */
     if (arg == 'n')
       {
         edit_structure = FALSE;
         break;
       }
+    /* -i imports a file */
     if (arg == 'i')
 		ifile = optarg;
+    /* -v edits owner's vcard */
     if (arg == 'v')
       edit_vcard = TRUE;
-  }    
-
+  }
+  
   /* are we called to import a file? */
   if (ifile)
     {
@@ -1563,35 +1599,44 @@ main (int argc, char *argv[])
   
   export_init ();
 
-  displaymigration_init ();
-  
- /* we are called to edit a users personal vcard */
+  /* we are called to edit a users personal vcard */
   if (edit_vcard)
     {
-      struct person *p;
+      struct contacts_person *p;
       const gchar *MY_VCARD = g_strdup_printf("%s/.gpe/user.vcf", 
                                               g_get_home_dir());
   
-      if (db_open (TRUE))
+      /* Open vcard database */
+      if (contacts_db_open (TRUE))
         exit (1);
       load_well_known_tags ();
-      load_structure ();
+      load_structure (LARGE_STRUCTURE);
       
-      p = db_get_by_uid (1);
+      p = contacts_db_get_by_uid (1);
       if (!p)
-        p = new_person();
+        p = contacts_new_person();
       edit_person (p, _("My Card"), TRUE);
       gtk_main();
       if (save_to_file(1, MY_VCARD))
         gpe_perror_box(_("Saving vcard failed"));
       exit (EXIT_SUCCESS);
     }
-    
-   if (db_open (FALSE))
-    exit (1);
+   
+   /* initialise data backends */ 
+   gpe_pim_categories_init ();
+ 
+   /* Open contacts database */
+   if (contacts_db_open (FALSE))
+     exit (1);
 
   load_well_known_tags ();
 
+  if (mode_large_screen)
+    load_structure (LARGE_STRUCTURE);
+  else
+    load_structure (DEFAULT_STRUCTURE);
+
+  /* crate main window and initialise display */
   list_store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT);
    
   mainw = create_main (edit_structure);
@@ -1601,20 +1646,18 @@ main (int argc, char *argv[])
 
   gtk_signal_connect (GTK_OBJECT (mainw), "destroy", gtk_main_quit, NULL);
 
-  load_structure ();
-
   /* load detail panel fields, create widgets */
   if (!mode_landscape)
     load_panel_config ();
 
   gpe_set_window_icon (mainw, "icon");
   gtk_widget_show_all (mainw);
-  gtk_widget_grab_focus (GTK_WIDGET (g_object_get_data (G_OBJECT (mainw), "entry")));
+  gtk_widget_grab_focus (GTK_WIDGET (mainw));
 
   path = gtk_tree_path_new_first();
   gtk_tree_view_set_cursor(GTK_TREE_VIEW(list_view), path, NULL, FALSE);
   gtk_tree_path_free(path);
-
+  
   gtk_main ();
   return 0;
 }
